@@ -1,10 +1,10 @@
 # Oxford University calendar conversion.
 # Simon Cozens (c) 1999-2002
 # Eugene van der Pijll (c) 2004
-# Dominic Hargreaves / University of Oxford (c) 2007-2008
+# Dominic Hargreaves / University of Oxford (c) 2007-2009
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.01";
+$Oxford::Calendar::VERSION = "2.03";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
@@ -306,8 +306,6 @@ If true, ignores dates marked as provisional in the database.
 
 =back
 
-=back
-
 =cut
 
 sub ToOx {
@@ -387,8 +385,6 @@ sub NextTerm {
     return @next_term;
 }
 
-=over 3
-
 =item StatutoryTermDates($year)
 
 Returns a hash reference keyed on terms for a given year, the value of
@@ -398,8 +394,6 @@ year, month, day values.
 
 Note: these are the statutory term dates, not full term dates.
 
-=back
-
 =cut
 
 sub StatutoryTermDates {
@@ -457,8 +451,6 @@ sub StatutoryTermDates {
     return $term_dates;
 }
 
-=over 3
-
 =item Parse($string)
 
 Takes a free-form description of an Oxford calendar date, and attempts
@@ -469,8 +461,6 @@ C<($year,$term,$week,$day)>.
 
 This function is experimental.
 
-=back
-
 =cut
 
 sub Parse {
@@ -532,8 +522,6 @@ sub Parse {
     return ( $year, $term, $week, $day );
 }
 
-=over 3
-
 =item FromOx($year, $term, $week, $day)
 
 Converts an Oxford date into a Georgian date, returning a string of the
@@ -567,6 +555,8 @@ sub FromOx {
 
 1;
 
+=back
+
 =head1 BUGS
 
 Bugs may be browsed and submitted at
@@ -580,8 +570,8 @@ Simon Cozens is the original author of this module.
 Eugene van der Pijll, C<pijll@cpan.org> took over maintenance from
 Simon for a time.
 
-Dominic Hargreaves currently maintains this module in his capacity as
-employee of the Computing Services, University of Oxford.
+Dominic Hargreaves currently maintains this module for the
+Computing Services, University of Oxford.
 
 =cut
 
@@ -610,7 +600,6 @@ Calendar:
     start: 17/01/2010
   Hilary 2011:
     start: 16/01/2011
-    provisional: 1
   Hilary 2012:
     start: 15/01/2012
     provisional: 1
@@ -620,6 +609,9 @@ Calendar:
   Hilary 2014:
     start: 19/01/2014
     provisional: 1
+  Hilary 2015:
+    start: 18/01/2015
+    provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
   Michaelmas 2002:
@@ -640,7 +632,6 @@ Calendar:
     start: 11/10/2009
   Michaelmas 2010:
     start: 10/10/2010
-    provisional: 1
   Michaelmas 2011:
     start: 09/10/2011
     provisional: 1
@@ -650,6 +641,9 @@ Calendar:
   Michaelmas 2013:
     start: 13/10/2013
     provisional: 1
+  Michaelmas 2014:
+    start: 12/10/2014
+    provisional: 1
   Trinity 2001:
     start: 22/04/2001
   Trinity 2002:
@@ -670,11 +664,8 @@ Calendar:
     start: 26/04/2009
   Trinity 2010:
     start: 25/04/2010
-  # Late Easter: as Easter falls on 24 April in 2011, Council will need to
-  # approve a seven-week vacation if the below Provisional Date is approved.
   Trinity 2011:
     start: 01/05/2011
-    provisional: 1
   Trinity 2012:
     start: 22/04/2012
     provisional: 1
@@ -684,3 +675,6 @@ Calendar:
   Trinity 2014:
     start: 27/04/2014
     provisional: 1
+  Trinity 2015:
+    start: 26/04/2015
+    provisional: 1
